"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.templateApps = exports.DappType = exports.createApp = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const chalk = require("chalk");
const init_1 = require("./init");
async function createApp(template, projectName, protocol) {
    try {
        console.log(`- Initializing dapp in ${projectName}`);
        const url = template.url;
        (0, child_process_1.execSync)(`git clone --quiet ${url} ${projectName}`);
        console.log(`${chalk.green("✓")} ${chalk.cyan(template.alias)} dapp initialized`);
        cleanUpFiles(projectName);
        process.chdir(projectName);
        await (0, init_1.init)(projectName, protocol, template.rootPath, template.framework, true);
        process.chdir("..");
        console.log(`${chalk.green("✓")} ${chalk.cyan(template.alias)} dapp created in ${projectName} 🚀`);
    }
    catch (error) {
        console.log(`✖️  Error: ${error.message}`);
    }
}
exports.createApp = createApp;
function cleanUpFiles(folderName) {
    fs_1.default.rmSync(path_1.default.join(process.cwd(), folderName, ".git"), {
        recursive: true,
        force: true,
    });
}
var DappType;
(function (DappType) {
    DappType["Default"] = "default";
    DappType["Template"] = "template";
})(DappType = exports.DappType || (exports.DappType = {}));
exports.templateApps = new Map([
    [
        "default-react",
        {
            alias: "React",
            dappType: DappType.Default,
            url: "https://github.com/spheronFdn/react-boilerplate",
            framework: init_1.FrameworkOptions.React,
            rootPath: "./",
            defaultProjectName: "my-react-app",
        },
    ],
    [
        "default-nextjs",
        {
            alias: "Next.js",
            dappType: DappType.Default,
            url: "https://github.com/spheronFdn/next-boilerplate",
            framework: init_1.FrameworkOptions.Next,
            rootPath: "./",
            defaultProjectName: "my-nextjs-app",
        },
    ],
    [
        "template-portfolio",
        {
            alias: "Portfolio",
            dappType: DappType.Template,
            url: "https://github.com/spheronFdn/portfolio-template",
            framework: init_1.FrameworkOptions.Next,
            rootPath: "./",
            defaultProjectName: "my-portfolio-app",
        },
    ],
]);
